==> py27-apgl-0.6.8.tbz: lib/python2.7/site-packages/apgl-0.6.8-py2.7.egg/apgl/util/test/LatexTest.py <==
import unittest
import numpy
import logging
from apgl.util import *

class  LatexTest(unittest.TestCase):
    def testArray1DToLatex(self):
        X = numpy.array([1.2323132, 5.324323, 8.3213232])
        self.assertEquals(Latex.array1DToRow(X, 3), "1.232 & 5.324 & 8.321")

        X = numpy.array([1, 2, 3], numpy.int)
        self.assertEquals(Latex.array1DToRow(X, 3), "1 & 2 & 3")

    def testArray2DToLatex(self):
        X = numpy.random.rand(5, 5)

        logging.debug((Latex.array2DToRows(X, 5)))

    def testListToLatex(self):
        lst = ["one", "two", "three"]

        self.assertEquals(Latex.listToRow(lst), "one & two & three\\\\")

        lst = []

        self.assertEquals(Latex.listToRow(lst), "")

    def testArray2DsToRows(self):
        numpy.random.seed(21)
        X = numpy.random.rand(2, 2)
        Y = numpy.random.rand(2, 2)

        outputStr = "0.049 (0.206) & 0.289 (0.051)\\\\\n"
        outputStr += "0.721 (0.302) & 0.022 (0.664)\\\\\n"

        self.assertTrue(Latex.array2DsToRows(X, Y) == outputStr)

    def testAddRowNames(self):
        numpy.random.seed(21)
        X = numpy.random.rand(2, 2)
        Y = numpy.random.rand(2, 2)

        latexTable = Latex.array2DsToRows(X, Y)
        rowNames = ["a", "b"]
        latexTable = Latex.addRowNames(rowNames, latexTable)

        outputStr = "a & 0.049 (0.206) & 0.289 (0.051)\\\\\n"
        outputStr += "b & 0.721 (0.302) & 0.022 (0.664)\\\\\n"

        self.assertTrue(latexTable == outputStr)

if __name__ == '__main__':
    unittest.main()

==> py27-apgl-0.6.9.tbz: lib/python2.7/site-packages/apgl-0.6.9-py2.7.egg/apgl/util/test/LatexTest.py <==
import unittest
import numpy
import logging
from apgl.util import *

class  LatexTest(unittest.TestCase):
    def testArray1DToLatex(self):
        X = numpy.array([1.2323132, 5.324323, 8.3213232])
        self.assertEquals(Latex.array1DToRow(X, 3), "1.232 & 5.324 & 8.321")

        X = numpy.array([1, 2, 3], numpy.int)
        self.assertEquals(Latex.array1DToRow(X, 3), "1 & 2 & 3")

    def testArray2DToLatex(self):
        X = numpy.random.rand(5, 5)

        logging.debug((Latex.array2DToRows(X, 5)))

    def testListToLatex(self):
        lst = ["one", "two", "three"]

        self.assertEquals(Latex.listToRow(lst), "one & two & three\\\\")

        lst = []

        self.assertEquals(Latex.listToRow(lst), "")

    def testArray2DsToRows(self):
        numpy.random.seed(21)
        X = numpy.random.rand(2, 2)
        Y = numpy.random.rand(2, 2)

        outputStr = "0.049 (0.206) & 0.289 (0.051)\\\\\n"
        outputStr += "0.721 (0.302) & 0.022 (0.664)\\\\"

        self.assertTrue(Latex.array2DsToRows(X, Y) == outputStr)

    def testAddRowNames(self):
        numpy.random.seed(21)
        X = numpy.random.rand(2, 2)
        Y = numpy.random.rand(2, 2)

        latexTable = Latex.array2DsToRows(X, Y)
        rowNames = ["a", "b"]
        latexTable = Latex.addRowNames(rowNames, latexTable)

        outputStr = "a & 0.049 (0.206) & 0.289 (0.051)\\\\\n"
        outputStr += "b & 0.721 (0.302) & 0.022 (0.664)\\\\\n"

        self.assertTrue(latexTable == outputStr)

if __name__ == '__main__':
    unittest.main()
